#n2-ss-editor-modal {
    position: fixed;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    display: none;
    z-index: 10000001;
    background-color: rgba(43, 52, 63, 0.9);
}

#n2-ss-editor-modal.n2-active {
    display: block;
}

.n2-ss-editor-inner {
    position: relative;
    top: 10%;
    max-width: 980px;
    height: 80%;
    margin: 0 auto;
    overflow: hidden;
    background: #fff;
}

.n2-ss-editor-header {
    position: relative;
    border-bottom: 1px solid #ccd1d6;
    border-top-left-radius: 3px;
    border-top-right-radius: 3px;
    overflow: hidden;
    background-color: #f2f5fa;
    line-height: 59px;
    height: 59px;
    padding: 0 58px;
    text-align: center;
    font-size: 20px;
    text-transform: capitalize;
    color: #6b7989;
}

.n2-ss-editor-header-close {
    position: absolute;
    top: 0;
    right: 0;
    width: 59px;
    height: 59px;
    background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAMAAABEpIrGAAAAGFBMVEW5w8m5w8m5w8m5w8myvMOzvMO4wsgAAABdt9D1AAAACHRSTlNhxZstF/D+AIlGn1gAAACzSURBVHgBhZNbjsQwCASb9/1vvGKRCDMTqesnjrrsODagFodKZIYovJYVTPOg9i10LDCvcoO08iGY7KRdTuwRLOb1YJJh/8LkWj/oGC3Iza8hI/TgjZmIskx7zSdBaXvvdATfBSJ8Bh6xSziwO4gxOo/dBaCJGnyMeQxIhaTVNW5eloJIr2vcvDwDmfXgN28yqUA/QTdJf5MeFD1qdln0ulnBsJKjRUvLnjcObz3evLT9/wD6sBe9VsZBUQAAAABJRU5ErkJggg==) center center no-repeat;
    cursor: pointer;
}

.n2-ss-editor-inner > iframe {
    width: 100%;
    height: 500px;
}

#elementor-panel .elementor-button-smartslider {
    background-color: #a4afb7;
    color: #fff;
    line-height: 26px;
    padding: 0 15px;
    text-transform: uppercase;
}